@@ -1,5 +1,6 @@
 from cement import Controller, ex
 from cement.utils.version import get_version_banner
+import ipdb
 from ..core.version import get_version
 from pprint import pprint as pp
 import os
@@ -72,8 +73,8 @@ class Base(Controller):
     def sg(self):
         from ..ext.aws_sg import get_sg, update_sg_to_ip
         profile = self.app.pargs.__dict__.get('profile') or self.app.pargs.__dict__.get('p') or 'default'
-        name = self.app.pargs.__dict__.get('name') or self.app.pargs.__dict__.get('n') or 'default'
-        
+        name = self.app.pargs.__dict__.get('name') or self.app.pargs.__dict__.get('n')
+
         # which ports to change
         ports = self.app.pargs.__dict__.get('ports') or self.app.pargs.__dict__.get('P')
         if ports: ports = [ int(p) for p in ports.split(',') ]
@@ -87,10 +88,12 @@ class Base(Controller):
         if sid: sid = int(sid)
 
         if self.app.pargs.action=='show':
-            pp(get_sg(name, profile, sid = sid))
+            pp(get_sg(profile, sid = sid))
 
         elif self.app.pargs.action=='update':
-            update_sg_to_ip(sg_name=self.app.pargs.name, profile=profile, ports=ports, messages=messages)
+            if not self.app.pargs.name: sg_name = get_sg(profile, sid = sid)[0]['GroupName']
+            else: sg_name = self.app.pargs.name
+            update_sg_to_ip(sg_name=sg_name, profile=profile, ports=ports, messages=messages)
 
         elif self.app.pargs.action=='ls':
             from ..ext.aws_sg import list_security_groups
@@ -185,6 +188,31 @@ class Base(Controller):
         else:
             raise NotImplementedError("Choose one of {ls, update, start, stop}")
 
+    @ex(
+        help="Display all available Fluidstack nodes.",
+        arguments=[
+            (['action'],{
+                "help" : "To show one of {avail, ls, start, stop}.",
+                "action" : "store"
+            }),
+            (['-r','--remote'],{
+                "help" : "Remote path on the target server",
+                "action": "store"
+            }),
+            (['-ip'],{
+                "help" : "IP of the target server",
+                "action" : "store"
+            }),
+            (['-p','--port'],{
+                "help" : "Port over which to run SFTP.",
+                "action" : "store"
+            })
+        ]
+    )
+    def stfp(self):
+        # whatever imports
+        from ..ext.sftp_conf import sftp_exists
+
     @ex(
         help="Display all available Fluidstack nodes.",
         arguments=[
@@ -210,23 +238,40 @@ class Base(Controller):
         from ..ext.fluidstack import avail_fl_nodes, show_running, \
             stop_container, start_container
 
-
         args = self.app.pargs
         if args.action=='avail':
             avail_fl_nodes(args.stats, args.n_gpu)
-
         elif args.action=='ls':
             show_running()
-
         elif args.action=='stop':
             stop_container(args.id)
-
         elif args.action=='start':
             start_container(args.id)
 
         else:
             raise NotImplementedError('Set the first parg to one of {avail, ls, start, stop}')
 
+    @ex(
+        help="Ops with Codex AI from OpenAI.",
+        arguments=[
+            (['text'],{
+                "help" : "Text to be suggested",
+                "action": "store"
+            }),
+            (['-n','--n_suggestions'],{
+                "help" : "Number of suggestions to return",
+                "action": "store",
+                "default": 5
+            })
+        ]
+    )
+    def cai(self):
+        from ..ext.codex import get_cai_suggestions
+        import pprint as pp
+
+        suggestions = get_cai_suggestions(self.app.pargs.text, self.app.pargs.n_suggestions)
+        pp.pprint(suggestions)
+
 
     @ex(
         help='Monitor lack of GPU activity. When there is none, runs -job',
@@ -317,7 +362,7 @@ class Base(Controller):
             excluded_terms = self.app.pargs.e or []
             if isinstance(excluded_terms, str): excluded_terms = excluded_terms.split(',')
             pp.pprint(hist_tail(n_lines, excluded_terms))
-        else: 
+        else:
             from ..ext.hist import hist_show
             print(hist_show(self.app.pargs.n))
 
