@@ -1,4 +1,5 @@
 import sys
+import ipdb
 import pandas as pd
 import datetime as dt
 import subprocess as sp
@@ -6,12 +7,14 @@ from Levenshtein import distance as dist
 import os
 import humanize
 
-term_wdith = os.get_terminal_size().columns
+try:
+    term_wdith = os.get_terminal_size().columns
+except OSError:
+    term_wdith = 80
 
 pd.set_option('display.max_colwidth',term_wdith - 20)
 
 # TODO: treat 'cd' in a special way s.t. we can generate the absolute path wherever possible
-# TODO: treat 'cd' in a specical way so that it can keep track of location.
 FILTER_TERMS = ['ls','install','dt hist', 'git ', 'dt ', 'code',
                 'ipython','htop','git push','git pull','git stash',
                 'tmux', 'nvidia-smi', 'ping']
@@ -19,11 +22,11 @@ FILTER_TERMS = ['ls','install','dt hist', 'git ', 'dt ', 'code',
 def dt_conv(l: str):
     try:
         # TODO: correct timezone? why does midnight show up as 4 pm?
-        pd_dt_repr = pd.to_datetime(dt.datetime.fromtimestamp(int(l[1].strip())))
+        pd_dt_repr = pd.to_datetime(dt.datetime.fromtimestamp(l[1]))
         return  humanize.naturaldelta(pd_dt_repr)
     except ValueError as e:
         # TODO: why does this occur
-        pass
+        print('ValueError', l)
 
 
 def filter_term(term: tuple, excluded_terms = FILTER_TERMS):
@@ -39,6 +42,13 @@ def filter_term(term: tuple, excluded_terms = FILTER_TERMS):
 
     return all([ft not in term[0] for ft in excluded_terms])
 
+def check_if_intlike(s:str):
+    try:
+        int(s)
+        return True
+    except ValueError:
+        return False
+
 def hist_tail(n_lines=20, excluded_terms = []):
     excluded_terms = FILTER_TERMS + excluded_terms
     
@@ -54,12 +64,14 @@ def hist_tail(n_lines=20, excluded_terms = []):
         # if not.path.exists(zsh_hist): raise NotImplementedError('Not sure where to look')
     # else:
         raise NotImplementedError('Not sure where to look')
-    split_f = str(sp.check_output(['tail',zsh_hist,'-n',str(n_lines * 5)])).split(':')
+    split_f = str(sp.check_output(['tail',zsh_hist,'-n',str(n_lines * 3)])).split(':')
 
     # TODO: \n -> \\n for Mac, check if this is an issue on Linux
     # Work Ubuntu 20.04 so far so good
+    # TODO: fix this horrible line 
     parsed_commands = [ ''.join(l.replace('\\n','').strip().split(';')[-1:]) for l in split_f if '\\n' in l]
-    parsed_dt = [ t for t in split_f if '\\n' not in t]
+    # check if an item in split_f is convertable to int
+    parsed_dt = [ int(t) for t in split_f if check_if_intlike(t)]
 
     parsed = list(zip(parsed_commands, parsed_dt))
 
